var data = [
  {
    brand_name: 'apple',
    model: 'Apple iPhone 14',
    processor_speed: 3.22,
  },
  {
    brand_name: 'motorola',
    model: 'Motorola Moto G62 5G',
    processor_speed: 2.2,
  },
  {
    brand_name: 'nothing',
    model: 'Nothing Phone 1',
    processor_speed: 2.5,
  },
  {
    brand_name: 'oneplus',
    model: 'OnePlus 11 5G',
    processor_speed: 3.2,
  },
  {
    brand_name: 'oneplus',
    model: 'OnePlus Nord 2T 5G',
    processor_speed: 3,
  },
  {
    brand_name: 'oneplus',
    model: 'OnePlus Nord CE 2 Lite 5G',
    processor_speed: 2.2,
  },
  {
    brand_name: 'oppo',
    model: 'Oppo A78',
    processor_speed: 2.2,
  },
  {
    brand_name: 'realme',
    model: 'Realme 10 Pro',
    processor_speed: 2.2,
  },
  {
    brand_name: 'realme',
    model: 'Realme 10 Pro Plus',
    processor_speed: 2.6,
  },
  {
    brand_name: 'samsung',
    model: 'Samsung Galaxy A14 5G',
    processor_speed: 2.4,
  },
  {
    brand_name: 'samsung',
    model: 'Samsung Galaxy F23 5G (6GB RAM + 128GB)',
    processor_speed: 2.2,
  },
  {
    brand_name: 'vivo',
    model: 'Vivo T1 5G (6GB RAM + 128GB)',
    processor_speed: 2.2,
  },
  {
    brand_name: 'xiaomi',
    model: 'Xiaomi Redmi Note 12 Pro 5G',
    processor_speed: 2.6,
  },
  {
    brand_name: 'xiaomi',
    model: 'Xiaomi Redmi Note 12 Pro Plus',
    processor_speed: 2.6,
  },
];

// Create hierarchy
var root = d3
  .stratify()
  .id(function (d) {
    return d.model;
  })
  .parentId(function (d) {
    return d.brand_name;
  })(data);

// Create tree layout
var treeLayout = d3.tree().size([800, 500]);

// Compute node and link data
var treeData = treeLayout(root);

// Append SVG
var svg = d3.select('svg#tree-graph');

// Draw links
svg
  .selectAll('.link')
  .data(treeData.links())
  .enter()
  .append('path')
  .attr('class', 'link')
  .attr(
    'd',
    d3
      .linkHorizontal()
      .x(function (d) {
        return d.y;
      })
      .y(function (d) {
        return d.x;
      }),
  );

// Draw nodes
var node = svg
  .selectAll('.node')
  .data(treeData.descendants())
  .enter()
  .append('g')
  .attr('class', 'node')
  .attr('transform', function (d) {
    return 'translate(' + d.y + ',' + d.x + ')';
  });

// Append circles to nodes
node
  .append('circle')
  .attr('r', 7)
  .style('fill', 'steelblue');

// Append text to nodes
node
  .append('text')
  .attr('dy', '.35em')
  .attr('x', function (d) {
    return d.children ? -13 : 13;
  })
  .style('text-anchor', function (d) {
    return d.children ? 'end' : 'start';
  })
  .text(function (d) {
    return d.data.model;
  });
